package com.mortals.xhx.module.ph.web;

import cn.hutool.core.date.DateTime;
import cn.hutool.core.date.DateUnit;
import cn.hutool.core.date.DateUtil;
import com.google.common.collect.Lists;
import com.mortals.framework.annotation.UnAuth;
import com.mortals.framework.common.Rest;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.framework.service.ICacheService;
import com.mortals.framework.util.ThreadPool;
import com.mortals.framework.web.BaseCRUDJsonBodyMappingController;
import com.mortals.xhx.common.code.AccessTypeEnum;
import com.mortals.xhx.common.code.GroupListEnum;
import com.mortals.xhx.common.code.StatTypeEnum;
import com.mortals.xhx.common.code.YesNoEnum;
import com.mortals.xhx.common.key.RedisKey;
import com.mortals.xhx.common.pdu.site.SitePdu;
import com.mortals.xhx.common.thread.PhStatThread;
import com.mortals.xhx.common.thread.StatThread;
import com.mortals.xhx.feign.site.ISiteFeign;
import com.mortals.xhx.module.access.model.AccessEntity;
import com.mortals.xhx.module.access.model.AccessQuery;
import com.mortals.xhx.module.access.model.AccessStatLogEntity;
import com.mortals.xhx.module.access.model.AccessSystemEntity;
import com.mortals.xhx.module.access.service.AccessService;
import com.mortals.xhx.module.access.service.AccessStatLogService;
import com.mortals.xhx.module.ph.model.PhQueueQuery;
import com.mortals.xhx.module.ph.model.PhQueueStatEntity;
import com.mortals.xhx.module.ph.service.PhQueueStatService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.ObjectUtils;
import org.springframework.util.StopWatch;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.*;
import java.util.stream.Collectors;

import static java.util.stream.Collectors.collectingAndThen;
import static java.util.stream.Collectors.toCollection;

/**
 * 排队叫号汇总统计
 *
 * @author zxfei
 * @date 2024-06-24
 */
@RestController
@RequestMapping("ph/queue/stat")
@Slf4j
public class PhQueueStatController extends BaseCRUDJsonBodyMappingController<PhQueueStatService, PhQueueStatEntity, Long> {

    @Autowired
    private ISiteFeign siteFeign;
    @Autowired
    private PhQueueStatService phQueueStatService;
    @Autowired
    private ICacheService cacheService;
    @Autowired
    private AccessService accessService;
    @Autowired
    private AccessStatLogService accessStatLogService;

    public PhQueueStatController() {
        super.setModuleDesc("排队叫号汇总统计");
    }

    @Override
    protected void init(Map<String, Object> model, Context context) {
        //通过站点 查询存在的部门 大厅等
        Object siteId = model.get("siteId");
        if (!ObjectUtils.isEmpty(siteId)) {
            Map<String, String> sectionNameMap = cacheService.hgetAll(RedisKey.KEY_SITE_QUEUE_SECTIONNAME_CHCHE + siteId);
            Map<String, String> hallNameMap = cacheService.hgetAll(RedisKey.KEY_SITE_QUEUE_HALLNAME_CHCHE + siteId);
            Map<String, String> windowFromnumMap = cacheService.hgetAll(RedisKey.KEY_SITE_QUEUE_WINDOW_CHCHE + siteId);
            Map<String, String> bussinessMap = cacheService.hgetAll(RedisKey.KEY_SITE_QUEUE_BUSNIESS_CHCHE + siteId);

            List<Map<String, String>> m1 = sectionNameMap.entrySet().stream()
                    .sorted((e1, e2) -> Integer.compare(Integer.parseInt(e2.getValue()), Integer.parseInt(e1.getValue())))
                    .map(item -> new HashMap<String, String>() {{
                        put(item.getKey(), item.getValue());
                    }}).collect(Collectors.toList());
            List<Map<String, String>> m2 = hallNameMap.entrySet().stream()
                    .sorted((e1, e2) -> Integer.compare(Integer.parseInt(e2.getValue()), Integer.parseInt(e1.getValue())))
                    .map(item -> new HashMap<String, String>() {{
                        put(item.getKey(), item.getValue());
                    }}).collect(Collectors.toList());
            List<Map<String, String>> m3 = windowFromnumMap.entrySet().stream()
                    .sorted((e1, e2) -> Integer.compare(Integer.parseInt(e2.getValue()), Integer.parseInt(e1.getValue())))
                    .map(item -> new HashMap<String, String>() {{
                        put(item.getKey(), item.getValue());
                    }}).collect(Collectors.toList());
            List<Map<String, String>> m4 = bussinessMap.entrySet().stream()
                    .sorted((e1, e2) -> Integer.compare(Integer.parseInt(e2.getValue()), Integer.parseInt(e1.getValue())))
                    .map(item -> new HashMap<String, String>() {{
                        put(item.getKey(), item.getValue());
                    }}).collect(Collectors.toList());

            this.addDict(model, "sectionNameList", m1);
            this.addDict(model, "hallNameList", m2);
            this.addDict(model, "windowFromnumList", m3);
            this.addDict(model, "businessList", m4);
            this.addDict(model, "groupList", GroupListEnum.getEnumMap());
        }

        super.init(model, context);
    }


    @Override
    protected void doListBefore(PhQueueStatEntity query, Map<String, Object> model, Context context) throws AppException {
        if (ObjectUtils.isEmpty(query.getHallName()) && ObjectUtils.isEmpty(query.getHallNameList()) && ObjectUtils.isEmpty(query.getHallNameNotList()))
            query.setHallNameList(Arrays.asList(""));
        if (ObjectUtils.isEmpty(query.getSectionName()) && ObjectUtils.isEmpty(query.getSectionNameList()) && ObjectUtils.isEmpty(query.getSectionNameNotList()))
            query.setSectionNameList(Arrays.asList(""));
        if (ObjectUtils.isEmpty(query.getBusiness()) && ObjectUtils.isEmpty(query.getBusinessList()) && ObjectUtils.isEmpty(query.getBusinessNotList()))
            query.setBusinessList(Arrays.asList(""));
        if (ObjectUtils.isEmpty(query.getWindowFromnum()) && ObjectUtils.isEmpty(query.getWindowFromnumList()) && ObjectUtils.isEmpty(query.getWindowFromnumNotList()))
            query.setWindowFromnumList(Arrays.asList(""));
        addGroup(query);
        model.put("siteId", query.getSiteId());
    }

    private static void addGroup(PhQueueStatEntity query) {
        if (!ObjectUtils.isEmpty(query.getSiteId())) {
            List<String> groupList = query.getGroupList();
            if (!groupList.contains("siteId")) {
                groupList.add("siteId");
            }
        }

        if (!ObjectUtils.isEmpty(query.getSectionName())
                || !ObjectUtils.isEmpty(query.getSectionNameList())
                || !ObjectUtils.isEmpty(query.getSectionNameNotList())) {
            List<String> groupList = query.getGroupList();
            if (!groupList.contains("sectionName")) {
                groupList.add("sectionName");
            }
        }
        if (!ObjectUtils.isEmpty(query.getHallName())
                || !ObjectUtils.isEmpty(query.getHallNameList())
                || !ObjectUtils.isEmpty(query.getHallNameNotList())) {
            List<String> groupList = query.getGroupList();
            if (!groupList.contains("hallName")) {
                groupList.add("hallName");
            }
        }

        if (!ObjectUtils.isEmpty(query.getWindowFromnum())
                || !ObjectUtils.isEmpty(query.getWindowFromnumList())
                || !ObjectUtils.isEmpty(query.getWindowFromnumNotList())) {
            List<String> groupList = query.getGroupList();
            if (!groupList.contains("windowFromnum")) {
                groupList.add("windowFromnum");
            }
        }

        if (!ObjectUtils.isEmpty(query.getBusiness())
                || !ObjectUtils.isEmpty(query.getBusinessList())
                || !ObjectUtils.isEmpty(query.getHallNameNotList())) {
            List<String> groupList = query.getGroupList();
            if (!groupList.contains("business")) {
                groupList.add("business");
            }
        }

    }

    @PostMapping(value = "/stat")
    @UnAuth
    public Rest<String> stat(@RequestBody PhQueueQuery phQueueQuery) {
        Rest<String> ret = new Rest();
        Map<String, Object> model = new HashMap();
        Context context = this.getContext();
        String busiDesc = "查询" + this.getModuleDesc();
        int code = 1;
        try {
            //天数区间分段计算
            DateTime attendStart = DateUtil.parseDate(phQueueQuery.getTaketimeStart());
            DateTime attendEnd = DateUtil.parseDate(phQueueQuery.getTaketimeEnd());
            Long compare = DateUtil.between(attendEnd, attendStart, DateUnit.DAY);
            log.info("计算天数区间：{}", compare);
            List<SitePdu> statSiteList = accessService.getStatSiteList( new AccessQuery());
            for (SitePdu site : statSiteList) {
                StatThread statThread = new StatThread(attendStart, compare, site, context, Arrays.asList(StatTypeEnum.STAT_PH.getValue()));
                ThreadPool.getInstance().execute(statThread);
            }
            model.put("message_info", busiDesc + "成功");
            this.recordSysLog(this.request, busiDesc + " 【成功】");
        } catch (Exception e) {
            code = -1;
            this.doException(this.request, busiDesc, model, e);
            model.put("message_info", e.getMessage());
        }

        this.init(model, context);
        ret.setCode(code);
        ret.setMsg(model.get("message_info") == null ? "" : model.remove("message_info").toString());
        return ret;
    }

    public static void main(String[] args) throws InterruptedException {
        StopWatch stopWatch = new StopWatch("stopwatch");
        stopWatch.start();
        Thread.sleep(1200);
        stopWatch.stop();

        System.out.println(stopWatch.getLastTaskTimeMillis());

        stopWatch.start();
        Thread.sleep(1200);
        stopWatch.stop();

        System.out.println(stopWatch.getLastTaskTimeMillis());

    }

}